==> sspse_1.0.0.tar.gz: sspse/src/posteriorcmpwpvis2.h <==
#ifndef POSTERIORCMPWPVIS2_H
#define POSTERIORCMPWPVIS2_H

void gcmpwpvis2 (int *pop12, int *pop21,
            int *K, 
            int *n1, 
            int *n2, 
            int *n0, 
            int *samplesize, int *burnin, int *interval,
            double *mu, double *dfmu, 
            double *sigma, double *dfsigma,
	    double *lnlam, double *nu,
            double *beta0muprior, double *beta0sigmaprior, 
            double *beta1muprior, double *beta1sigmaprior, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *Npi,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *srd2, 
            int *numrec2, 
            double *rectime2,
            int *rc, 
            int *maxcoupons,
            double *muproposal, 
            double *nuproposal, 
            double *beta0proposal, double *beta1proposal, 
            double *lmemmuproposal, double *memnuproposal,
            int *N, int *maxN, 
            double *sample, 
            int *vsample, 
            int *vsample2, 
            double *posu, 
            double *posd, 
            double *lpriorm, 
            int *burnintheta,
            int *burninbeta,
            int *verbose
			 );

void MHwpmem2 (int *d1, int *d2, int *n1, int *n2, int *K,
            double *beta0, double *beta0s, double *beta1, double *beta1s, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *srd2, 
            int *numrec2, 
            double *rectime2,
            int *maxcoupons,
            double *beta0proposal, double *beta1proposal, 
            double *lmemmuproposal, double *memnuproposal, 
            double *beta0sample, double *beta1sample,
            double *lmemmusample, double *memnusample,
            int *samplesize, int *staken, int *burninbeta, int *interval,
            int *verbose
         );
#endif /* POSTERIORCMPWPVIS2_H */

==> sspse_1.1.0-2.tar.gz: sspse/src/posteriorcmpwpvis2.h <==
#ifndef POSTERIORCMPWPVIS2_H
#define POSTERIORCMPWPVIS2_H

void gcmpwpvis2 (int *pop12, int *pop21,
            int *K,
            int *n1,
            int *n2,
            int *n0,
            int *samplesize, int *burnin, int *interval,
            double *mu, double *dfmu,
            double *sigma, double *dfsigma,
            double *lnlam, double *nu,
            double *beta0muprior, double *beta0sigmaprior,
            double *betatmuprior, double *betatsigmaprior,
            double *betaumuprior, double *betausigmaprior,
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *Npi,
            int *srd,
            int *numrec,
            double *rectime,
            int *srd2,
            int *numrec2,
            double *rectime2,
            int *rc,
            int *maxcoupons,
            double *muproposal,
            double *nuproposal,
            double *beta0proposal, double *betatproposal, double *betauproposal,
            double *lmemmuproposal, double *memnuproposal,
            int *N, int *maxN,
            double *sample,
            int *vsample,
            int *vsample2,
            double *posu,
            double *posd,
            double *lpriorm,
            int *burnintheta,
            int *burninbeta,
            int *verbose
                         );
void MHwpmem2 (int *d1, int *d2, int *n1, int *n2, int *K,
            double *beta0, double *beta0s, double *betat, double *betats, double *betau, double *betaus,
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *srd,
            int *numrec,
            double *rectime,
            int *srd2,
            int *numrec2,
            double *rectime2,
            int *maxcoupons,
            double *beta0proposal, double *betatproposal, double *betauproposal,
            double *lmemmuproposal, double *memnuproposal,
            double *beta0sample, double *betatsample, double *betausample,
            double *lmemmusample, double *memnusample,
            int *samplesize, int *staken, int *burninbeta, int *interval,
            int *verbose
         );

#endif /* POSTERIORCMPWPVIS2_H */
